import { EuiButton, EuiIcon } from '@elastic/eui'
import cx from 'classnames'
import React from 'react'
import { CodeButtonParams, ExecuteButtonMode } from 'uiSrc/pages/workbench/components/enablement-area/interfaces'
import { truncateText } from 'uiSrc/utils'

import styles from './styles.module.scss'

export interface Props {
  onClick: (execute: { mode?: ExecuteButtonMode, params?: CodeButtonParams }) => void
  label: string
  isLoading?: boolean
  disabled?: boolean
  className?: string
  params?: CodeButtonParams
  mode?: ExecuteButtonMode
}
const CodeButton = ({ onClick, label, isLoading, className, disabled, params, mode, ...rest }: Props) => {
  const isAutoExecute = mode === ExecuteButtonMode.Auto

  return (
    <EuiButton
      iconSide="right"
      isLoading={isLoading}
      size="s"
      onClick={() => onClick({ mode, params })}
      fullWidth
      color="secondary"
      className={cx(className, styles.button)}
      textProps={{ className: styles.buttonText }}
      data-testid={`preselect-${isAutoExecute ? 'auto-' : ''}${label}`}
      disabled={disabled}
      {...rest}
    >
      <>
        {truncateText(label, 86)}
        {isAutoExecute && (
          <EuiIcon
            className={styles.autoExecuteIcon}
            type="playFilled"
          />
        )}
      </>
    </EuiButton>
  )
}

export default CodeButton
